import { useState, useEffect } from "react";
import { useMutation } from "@tanstack/react-query";
import { apiRequest } from "@/lib/queryClient";
import { useToast } from "@/hooks/use-toast";
import Header from "@/components/header";
import Footer from "@/components/footer";
import AIChatbot from "@/components/ai-chatbot";
import { Mail, Phone, MapPin, Clock } from "lucide-react";

interface FormData {
  name: string;
  email: string;
  message: string;
  recaptchaToken?: string;
}

interface FormErrors {
  name?: string;
  email?: string;
  message?: string;
}

export default function ContactPage() {
  const [formData, setFormData] = useState<FormData>({
    name: "",
    email: "",
    message: "",
  });
  const [errors, setErrors] = useState<FormErrors>({});
  const [recaptchaToken, setRecaptchaToken] = useState<string | null>(null);
  const { toast } = useToast();
  
  const RECAPTCHA_SITE_KEY = "6Lc4ymQrAAAAAMd8HUwavwwKe1ZBbELuoZyTyDx_";

  useEffect(() => {
    console.log('reCAPTCHA Enterprise Site Key configured');
    
    // Add the reCAPTCHA callback function to window
    (window as any).onRecaptchaSubmit = (token: string) => {
      console.log('reCAPTCHA token received:', token ? 'Token received' : 'Token cleared');
      setRecaptchaToken(token);
    };

    return () => {
      delete (window as any).onRecaptchaSubmit;
    };
  }, []);

  useEffect(() => {
    // Setup scroll animations
    const observerOptions = {
      threshold: 0.1,
      rootMargin: "0px 0px -50px 0px",
    };

    const observer = new IntersectionObserver((entries) => {
      entries.forEach((entry) => {
        if (entry.isIntersecting) {
          entry.target.classList.add("visible");
        }
      });
    }, observerOptions);

    const animateElements = document.querySelectorAll(".fade-in");
    animateElements.forEach((el) => {
      observer.observe(el);
    });

    return () => {
      animateElements.forEach((el) => {
        observer.unobserve(el);
      });
    };
  }, []);

  const contactMutation = useMutation({
    mutationFn: async (data: FormData) => {
      const response = await apiRequest("POST", "/api/contact", data);
      return response.json();
    },
    onSuccess: (data) => {
      toast({
        title: "Успешно изпратено!",
        description: data.message,
      });
      setFormData({ name: "", email: "", message: "" });
      setRecaptchaToken(null);
      setErrors({});
    },
    onError: () => {
      toast({
        title: "Грешка",
        description:
          "Възникна грешка при изпращането на съобщението. Моля, опитайте отново.",
        variant: "destructive",
      });
      setRecaptchaToken(null);
    },
  });

  const validateForm = (): boolean => {
    const newErrors: FormErrors = {};

    if (!formData.name.trim()) {
      newErrors.name = "Моля, въведете вашето име";
    }

    if (!formData.email.trim()) {
      newErrors.email = "Моля, въведете имейл адрес";
    } else if (!/^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(formData.email)) {
      newErrors.email = "Моля, въведете валиден имейл адрес";
    }

    if (!formData.message.trim()) {
      newErrors.message = "Моля, въведете вашето съобщение";
    }

    // reCAPTCHA Enterprise v3 handles validation automatically

    setErrors(newErrors);
    return Object.keys(newErrors).length === 0;
  };

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    if (!validateForm()) return;
    
    // Use reCAPTCHA Enterprise to execute and get token
    if ((window as any).grecaptcha) {
      (window as any).grecaptcha.enterprise.execute(RECAPTCHA_SITE_KEY, {action: 'submit'}).then((token: string) => {
        contactMutation.mutate({
          ...formData,
          recaptchaToken: token
        });
      });
    } else {
      // Fallback if reCAPTCHA is not loaded
      contactMutation.mutate({
        ...formData,
        recaptchaToken: 'no_recaptcha'
      });
    }
  };

  const handleChange = (
    e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>,
  ) => {
    const { name, value } = e.target;
    setFormData((prev) => ({
      ...prev,
      [name]: value,
    }));

    // Clear error when user starts typing
    if (errors[name as keyof FormErrors]) {
      setErrors((prev) => ({
        ...prev,
        [name]: undefined,
      }));
    }
  };

  const contactInfo = [
    {
      icon: MapPin,
      title: "Адрес",
      details: ["София 1000, България"],
    },
    {
      icon: Phone,
      title: "Телефон",
      details: ["+359 88 3377917"],
    },
    {
      icon: Mail,
      title: "Имейл",
      details: ["info@aiconsult.digital", "toma@aiconsult.digital"],
    },
    {
      icon: Clock,
      title: "Работно време",
      details: ["Пон-Пет: 9:00 - 18:00", "Събота: 10:00 - 14:00"],
    },
  ];

  return (
    <>
      <Header />
      <main className="pt-16">
        {/* Hero Section */}
        <section className="min-h-[60vh] flex items-center justify-center px-4 bg-gradient-to-br from-slate-50 to-blue-50 relative overflow-hidden">
          <div className="absolute top-0 right-0 w-96 h-96 bg-gradient-to-r from-purple-400/20 to-blue-400/20 rounded-full blur-3xl float-animation"></div>

          <div className="text-center max-w-4xl z-10 relative">
            <h1 className="text-5xl md:text-6xl font-bold mb-6 gradient-text leading-tight fade-in">
              Свържете се с нас
            </h1>

            <p className="text-xl md:text-2xl mb-8 text-gray-600 font-light max-w-2xl mx-auto fade-in">
              Готови сме да обсъдим вашия следващ проект и да ви помогнем да
              постигнете целите си
            </p>
          </div>
        </section>

        {/* Contact Form & Info */}
        <section className="py-20 px-4 max-w-7xl mx-auto">
          <div className="grid grid-cols-1 lg:grid-cols-2 gap-12">
            {/* Contact Form */}
            <div className="fade-in">
              <h2 className="text-3xl font-bold text-gray-800 mb-8">
                Изпратете ни съобщение
              </h2>

              <form onSubmit={handleSubmit} className="glass rounded-3xl p-8">
                <div className="space-y-6">
                  <div>
                    <label
                      htmlFor="name"
                      className="block text-sm font-medium text-gray-700 mb-2"
                    >
                      Име *
                    </label>
                    <input
                      type="text"
                      id="name"
                      name="name"
                      value={formData.name}
                      onChange={handleChange}
                      className={`w-full px-4 py-3 rounded-xl border-2 transition-all bg-white/50 backdrop-blur-sm focus:outline-none focus:ring-4 focus:ring-purple-500/20 ${
                        errors.name
                          ? "border-red-500 bg-red-50/50"
                          : "border-white/30 focus:border-purple-500"
                      }`}
                      placeholder="Вашето име"
                      required
                    />
                    {errors.name && (
                      <p className="error-message mt-1">{errors.name}</p>
                    )}
                  </div>

                  <div>
                    <label
                      htmlFor="email"
                      className="block text-sm font-medium text-gray-700 mb-2"
                    >
                      Имейл *
                    </label>
                    <input
                      type="email"
                      id="email"
                      name="email"
                      value={formData.email}
                      onChange={handleChange}
                      className={`w-full px-4 py-3 rounded-xl border-2 transition-all bg-white/50 backdrop-blur-sm focus:outline-none focus:ring-4 focus:ring-purple-500/20 ${
                        errors.email
                          ? "border-red-500 bg-red-50/50"
                          : "border-white/30 focus:border-purple-500"
                      }`}
                      placeholder="your@email.com"
                      required
                    />
                    {errors.email && (
                      <p className="error-message mt-1">{errors.email}</p>
                    )}
                  </div>

                  <div>
                    <label
                      htmlFor="message"
                      className="block text-sm font-medium text-gray-700 mb-2"
                    >
                      Съобщение *
                    </label>
                    <textarea
                      id="message"
                      name="message"
                      value={formData.message}
                      onChange={handleChange}
                      rows={6}
                      placeholder="Разкажете ни за вашия проект или как можем да ви помогнем..."
                      className={`w-full px-4 py-3 rounded-xl border-2 transition-all bg-white/50 backdrop-blur-sm focus:outline-none focus:ring-4 focus:ring-purple-500/20 resize-vertical ${
                        errors.message
                          ? "border-red-500 bg-red-50/50"
                          : "border-white/30 focus:border-purple-500"
                      }`}
                      required
                    />
                    {errors.message && (
                      <p className="error-message mt-1">{errors.message}</p>
                    )}
                  </div>

                  {/* reCAPTCHA Enterprise Note */}
                  <div className="text-center">
                    <p className="text-xs text-gray-500">
                      Този формуляр е защитен от reCAPTCHA Enterprise
                    </p>
                  </div>

                  <button
                    type="submit"
                    disabled={contactMutation.isPending}
                    className="w-full gradient-button py-4 rounded-xl text-lg font-semibold shadow-xl transition-all disabled:opacity-50 disabled:cursor-not-allowed"
                  >
                    {contactMutation.isPending
                      ? "Изпраща..."
                      : "Изпрати съобщение"}
                  </button>
                  
                  {/* Privacy Policy Agreement */}
                  <div className="text-center mt-4">
                    <p className="text-xs text-gray-600">
                      С изпращането на този формуляр, вие се съгласявате с нашата{" "}
                      <a 
                        href="/privacy-policy" 
                        className="text-purple-600 hover:text-purple-800 underline transition-colors"
                        target="_blank"
                        rel="noopener noreferrer"
                      >
                        Политика за поверителност
                      </a>
                    </p>
                  </div>
                </div>
              </form>
            </div>

            {/* Contact Information */}
            <div className="fade-in">
              <h2 className="text-3xl font-bold text-gray-800 mb-8">
                Информация за контакт
              </h2>

              <div className="space-y-8">
                {contactInfo.map((info, index) => {
                  const IconComponent = info.icon;
                  return (
                    <div key={index} className="flex items-start space-x-4">
                      <div className="w-12 h-12 bg-gradient-to-r from-purple-500 to-blue-500 rounded-full flex items-center justify-center flex-shrink-0">
                        <IconComponent className="w-5 h-5 text-white" />
                      </div>
                      <div>
                        <h3 className="text-lg font-semibold text-gray-800 mb-2">
                          {info.title}
                        </h3>
                        {info.details.map((detail, idx) => (
                          <p key={idx} className="text-gray-600">
                            {detail}
                          </p>
                        ))}
                      </div>
                    </div>
                  );
                })}
              </div>
            </div>
          </div>
        </section>

        {/* FAQ Section */}
        <section className="py-20 px-4 bg-gray-50">
          <div className="max-w-7xl mx-auto">
            <div className="text-center mb-16">
              <h2 className="text-4xl md:text-5xl font-bold text-gray-800 mb-4 fade-in">
                Често задавани въпроси
              </h2>
              <p className="text-xl md:text-2xl text-gray-600 font-light max-w-3xl mx-auto fade-in">
                Отговори на най-често срещаните въпроси за нашите AI решения и
                услуги
              </p>
            </div>

            <div className="grid grid-cols-1 lg:grid-cols-2 gap-6 max-w-6xl mx-auto">
              {[
                {
                  question:
                    "Какво представляват AI решенията, които предлагате?",
                  answer:
                    "Нашите AI решения са персонализирани системи за автоматизация, анализ и оптимизация на бизнес процеси според нуждите на вашата компания.",
                },
                {
                  question:
                    "Колко време отнема внедряването на AI в моя бизнес?",
                  answer:
                    "Времето за внедряване зависи от сложността на проекта, но обикновено процесът отнема между 4 и 12 седмици.",
                },
                {
                  question:
                    "Могат ли AI решенията да се интегрират със съществуващите ми платформи?",
                  answer:
                    "Да, разработваме индивидуални конектори и осигуряваме пълна интеграция с най-популярните бизнес платформи.",
                },
                {
                  question:
                    "Какви са изискванията за сигурност на вашите AI продукти?",
                  answer:
                    "Всички наши AI решения покриват най-високите стандарти за сигурност и могат да работят с локално внедряване за пълен контрол върху данните.",
                },
                {
                  question: "Каква е цената на вашите услуги?",
                  answer:
                    "Предлагаме прозрачни абонаментни планове, които започват от 250 EUR на месец, в зависимост от обхвата и нуждите на вашия бизнес.",
                },
                {
                  question:
                    "Предлагате ли техническа поддръжка след внедряването?",
                  answer:
                    "Да, осигуряваме 24/7 техническа поддръжка и редовни актуализации за всички наши AI решения.",
                },
                {
                  question:
                    "Подходящи ли са вашите решения за малки и средни предприятия?",
                  answer:
                    "Абсолютно! Разработваме мащабируеми решения, подходящи за компании с над 30 служители, независимо от размера.",
                },
                {
                  question:
                    "Какво прави вашите AI решения различни от конкуренцията?",
                  answer:
                    "Фокусираме се върху персонализирани решения, локално внедряване за пълна сигурност и прозрачно ценообразуване без скрити такси.",
                },
              ].map((faq, index) => (
                <div key={index} className="glass rounded-2xl p-6 fade-in">
                  <h3 className="text-lg font-semibold text-gray-800 mb-3">
                    {faq.question}
                  </h3>
                  <p className="text-gray-600 leading-relaxed">{faq.answer}</p>
                </div>
              ))}
            </div>

            <div className="text-center mt-16 fade-in">
              <p className="text-lg text-gray-600 mb-6">
                Не намерихте отговор на вашия въпрос?
              </p>
              <button className="gradient-button px-8 py-4 rounded-full text-lg font-semibold shadow-2xl hover:shadow-3xl transition-all transform hover:scale-105">
                Свържете се с нас
              </button>
            </div>
          </div>
        </section>

        {/* CTA Section */}
        <section className="py-20 px-4 bg-gradient-to-r from-purple-600 to-blue-600 text-white">
          <div className="max-w-4xl mx-auto text-center">
            <h2 className="text-4xl md:text-5xl font-bold mb-6 fade-in">
              Започнете проекта си днес
            </h2>
            <p className="text-xl mb-8 opacity-90 fade-in">
              Получете безплатна консултация и персонализирана оферта за вашия
              проект
            </p>
            <div className="flex flex-col sm:flex-row gap-4 justify-center fade-in">
              <button className="bg-white text-purple-600 px-8 py-4 rounded-full text-lg font-semibold hover:bg-gray-100 transition-all transform hover:scale-105">
                Безплатна консултация
              </button>
              <button className="border-2 border-white text-white px-8 py-4 rounded-full text-lg font-semibold hover:bg-white hover:text-purple-600 transition-all">
                Виж цени
              </button>
            </div>
          </div>
        </section>
      </main>
      <Footer />
      <AIChatbot />
    </>
  );
}
